## Summary

<!-- 1-3 bullet points describing the change -->

## Type

- [ ] Bug fix
- [ ] New tool
- [ ] Enhancement to existing tool
- [ ] Documentation
- [ ] Tests

## Checklist

- [ ] All tests pass (`pytest`)
- [ ] Lint passes (`ruff check src/`)
- [ ] New tool registered in both `server.py` and `cli.py`
- [ ] Tests added for new functionality
- [ ] README updated (if adding/changing tools)
